==> haskell-warp-tls-3.4.9-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp-tls
version:              3.4.9
visibility:           public
id:                   warp-tls-3.4.9-Icg9woSm9mbEZ2usdxIruP
key:                  warp-tls-3.4.9-Icg9woSm9mbEZ2usdxIruP
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.

category:             Web, Yesod
abi:                  bc3c769cff8ed27b214fa7f42f848dbc
exposed:              True
exposed-modules:
    Network.Wai.Handler.WarpTLS Network.Wai.Handler.WarpTLS.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-tls
hs-libraries:         HSwarp-tls-3.4.9-Icg9woSm9mbEZ2usdxIruP
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    network-3.1.4.0-ExLckjbUqaB9dQ68XDq8jI
    recv-0.1.0-9hH4IJ15gdTBKWZ2MS5QBu
    streaming-commons-0.2.2.6-HSb1rjyT3eQHSZhqaZNoY8
    tls-1.9.0-6fFEJEFVlAuLmY8ORA70oE
    tls-session-manager-0.0.4-AVCICZBSnGV9AsJ05E35aF
    unliftio-0.2.25.1-KoAUwIIyk4m4OHQUsvge0I
    wai-3.2.4-KXaRlag2H8u14yPy2nJnqM warp-3.3.30-Dl0dGRDWV133XOwu4MlsFM

haddock-interfaces:   /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html:         /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-tls-3.4.9-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp-tls
version:              3.4.9
visibility:           public
id:                   warp-tls-3.4.9-Ipa8JIii3KjKOpBdzWRGHM
key:                  warp-tls-3.4.9-Ipa8JIii3KjKOpBdzWRGHM
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.

category:             Web, Yesod
abi:                  f032bb6cd73807c04d8d12afa80700a2
exposed:              True
exposed-modules:
    Network.Wai.Handler.WarpTLS Network.Wai.Handler.WarpTLS.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-tls
hs-libraries:         HSwarp-tls-3.4.9-Ipa8JIii3KjKOpBdzWRGHM
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    network-3.1.4.0-HsnWpJCBJSkHDu8PyPRvYR
    recv-0.1.0-7LxCp5Z3M2FGwCEX80W2Zv
    streaming-commons-0.2.2.6-Bv2KVjCRVLl43v538HS7ua
    tls-1.9.0-Hbx0RiAqSbl7mRFwtSKZOx
    tls-session-manager-0.0.4-9njmmgMHcUQ3e48mSaNmpz
    unliftio-0.2.25.1-4Wsc1Zb3eoWC4jfumimD4V
    wai-3.2.4-GUoXUoY24VCBryLqTBaLdB warp-3.3.30-BGR5Wbz9ZcR2jBwEhCRmIG

haddock-interfaces:   /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html:         /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
